"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchedularHandler = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const domain_1 = require("../domain");
const MS_NAME = utility_1.ServiceMeta[12].friendlyName;
const LOCK_TIMEOUT_IN_MS = 60000;
class SchedularHandler {
    constructor(_jobSchedularCommand, jfrogPipelineSessionId) {
        this.jfrogPipelineSessionId = jfrogPipelineSessionId;
        this.logger = logger_1.LoggerFactory.getLogger(`FeatureAwareSchedularHandler`);
        this.systemInstanceId = microservice_1.applicationContext.get(microservice_1.SYSTEM_SERVICE_INSTANCE_INITIALIZER)
            ?.systemServiceInstancesId;
    }
    async handle() {
        const lock = await this.getLock();
        if (lock) {
            const schedularRootAggregate = new domain_1.SchedularRootAggregate(lock, this.jfrogPipelineSessionId);
            await schedularRootAggregate.process();
        }
    }
    async getLock() {
        try {
            const lock = new microservice_1.Lock(this.systemInstanceId, MS_NAME, LOCK_TIMEOUT_IN_MS);
            await lock.obtainLock();
            return lock;
        }
        catch (error) {
            this.logger.info(`Cannot get lock with name: ${MS_NAME}. Facing error: ${(0, node_util_1.inspect)(error)}. Exiting!`);
            return null;
        }
    }
}
exports.SchedularHandler = SchedularHandler;
//# sourceMappingURL=SchedularHandler.js.map